@@ -59,11 +59,11 @@ def encode_value(v):
     then enclose it in curly braces and escape all right curly braces.
     """
     print('v-> ', v)
-    try:
-        if ';' in v or v.strip(' ').startswith('{'):
-            return '{%s}' % (v.replace('}', '}}'),)
-    except:
-        print('An exception occurred')
+    # try:
+    if ';' in v or v.strip(' ').startswith('{'):
+        return '{%s}' % (v.replace('}', '}}'),)
+    # except:
+    #     print('An exception occurred')
     return v
 
 
